citation-url |release| Documentation
====================================
Parse URLs for DOIs, PubMed identifiers, PMC identifiers, arXiv identifiers, etc.

Installation
------------
The most recent release can be installed from
`PyPI <https://pypi.org/project/citation_url>`_ with:

.. code-block:: shell

    $ pip install citation_url

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/citation-url.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/cthoyt/citation-url.git
    $ cd citation-url
    $ pip install -e .

Usage
-----
.. automodule:: citation_url
    :members:
